"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
var path = require("path");
var fs = require("fs");
var Datauri = require('datauri');
var url = require('rework-plugin-url');
/**
 *  Enum that decides what action to take if a problem is detected.
 */
var Action;
(function (Action) {
    /** Ignore the error and continue */
    Action["IGNORE"] = "";
    /** Warn about the error and continue */
    Action["WARN"] = "warn";
    /** Warn about the error and break */
    Action["ERROR"] = "error";
})(Action = exports.Action || (exports.Action = {}));
;
;
function base64(baseDir, options) {
    var opts = Object.assign({
        include: [],
        exclude: [/.*/],
        maxImageSize: 8192,
        breakOnMissingFile: 'error',
        breakOnLargeFile: 'warn',
        breakOnEncodedTwice: 'warn'
    }, options);
    var cache = {};
    function error(value, action, url, msg) {
        msg = 'Image file ' + url + ' ' + msg;
        if (action === 'error') {
            console.error(msg);
            throw new Error(msg);
        }
        else if (action === 'warn') {
            console.warn(msg);
        }
        return value;
    }
    function matches(url) {
        return !url.startsWith('data:') &&
            (opts.include.some(function (re) { return !!url.match(re); }) || !opts.exclude.some(function (re) { return !!url.match(re); }));
    }
    return url(function (url) {
        if (matches(url)) {
            if (cache[url]) {
                return error(cache[url], opts.breakOnEncodedTwice, url, "is encoded more than once");
            }
            else {
                var file = path.resolve(baseDir, url);
                if (fs.existsSync(file)) {
                    var data = new Datauri(file);
                    if (data.content.length < opts.maxImageSize) {
                        cache[url] = data.content;
                        return data.content;
                    }
                    else {
                        return error(url, opts.breakOnLargeFile, url, 'is too large');
                    }
                }
                else {
                    return error(url, opts.breakOnMissingFile, url, 'is missing');
                }
            }
        }
        else {
            return url;
        }
    });
}
exports.base64 = base64;
//# sourceMappingURL=index.js.map